# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('vercel')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def api_token(self) -> Optional[str]:
        """
        The Vercel API Token to use. This can also be specified with the `VERCEL_API_TOKEN` shell environment variable. Tokens can be created from your [Vercel settings](https://vercel.com/account/tokens).
        """
        return __config__.get('apiToken')

    @_builtins.property
    def team(self) -> Optional[str]:
        """
        The default Vercel Team to use when creating resources or reading data sources. This can be provided as either a team slug, or team ID. The slug and ID are both available from the Team Settings page in the Vercel dashboard.
        """
        return __config__.get('team')




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectMembersResult',
    'AwaitableGetProjectMembersResult',
    'get_project_members',
    'get_project_members_output',
]

@pulumi.output_type
class GetProjectMembersResult:
    """
    A collection of values returned by getProjectMembers.
    """
    def __init__(__self__, id=None, members=None, project_id=None, team_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def members(self) -> Sequence['outputs.GetProjectMembersMemberResult']:
        """
        The set of members in this project.
        """
        return pulumi.get(self, "members")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The ID of the Vercel Project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The team ID to which the project belongs. Required when accessing a team project if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")


class AwaitableGetProjectMembersResult(GetProjectMembersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectMembersResult(
            id=self.id,
            members=self.members,
            project_id=self.project_id,
            team_id=self.team_id)


def get_project_members(project_id: Optional[_builtins.str] = None,
                        team_id: Optional[_builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectMembersResult:
    """
    Retrieves members and their roles for a Vercel Project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_project(name="example-with-members")
    example_get_project_members = vercel.get_project_members(project_id=example.id)
    ```


    :param _builtins.str project_id: The ID of the Vercel Project.
    :param _builtins.str team_id: The team ID to which the project belongs. Required when accessing a team project if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getProjectMembers:getProjectMembers', __args__, opts=opts, typ=GetProjectMembersResult).value

    return AwaitableGetProjectMembersResult(
        id=pulumi.get(__ret__, 'id'),
        members=pulumi.get(__ret__, 'members'),
        project_id=pulumi.get(__ret__, 'project_id'),
        team_id=pulumi.get(__ret__, 'team_id'))
def get_project_members_output(project_id: Optional[pulumi.Input[_builtins.str]] = None,
                               team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectMembersResult]:
    """
    Retrieves members and their roles for a Vercel Project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_project(name="example-with-members")
    example_get_project_members = vercel.get_project_members(project_id=example.id)
    ```


    :param _builtins.str project_id: The ID of the Vercel Project.
    :param _builtins.str team_id: The team ID to which the project belongs. Required when accessing a team project if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getProjectMembers:getProjectMembers', __args__, opts=opts, typ=GetProjectMembersResult)
    return __ret__.apply(lambda __response__: GetProjectMembersResult(
        id=pulumi.get(__response__, 'id'),
        members=pulumi.get(__response__, 'members'),
        project_id=pulumi.get(__response__, 'project_id'),
        team_id=pulumi.get(__response__, 'team_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SharedEnvironmentVariableArgs', 'SharedEnvironmentVariable']

@pulumi.input_type
class SharedEnvironmentVariableArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[_builtins.str],
                 project_ids: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 apply_to_all_custom_environments: Optional[pulumi.Input[_builtins.bool]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 sensitive: Optional[pulumi.Input[_builtins.bool]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_wo: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SharedEnvironmentVariable resource.
        :param pulumi.Input[_builtins.str] key: The name of the Environment Variable.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] project_ids: The ID of the Vercel project.
        :param pulumi.Input[_builtins.bool] apply_to_all_custom_environments: Whether the shared environment variable should be applied to all custom environments in the linked projects.
        :param pulumi.Input[_builtins.str] comment: A comment explaining what the environment variable is for.
        :param pulumi.Input[_builtins.bool] sensitive: Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] targets: The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team. Shared environment variables require a team.
        :param pulumi.Input[_builtins.str] value: (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        :param pulumi.Input[_builtins.str] value_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
               (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "project_ids", project_ids)
        if apply_to_all_custom_environments is not None:
            pulumi.set(__self__, "apply_to_all_custom_environments", apply_to_all_custom_environments)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if sensitive is not None:
            pulumi.set(__self__, "sensitive", sensitive)
        if targets is not None:
            pulumi.set(__self__, "targets", targets)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if value_wo is not None:
            pulumi.set(__self__, "value_wo", value_wo)

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the Environment Variable.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="projectIds")
    def project_ids(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        The ID of the Vercel project.
        """
        return pulumi.get(self, "project_ids")

    @project_ids.setter
    def project_ids(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "project_ids", value)

    @_builtins.property
    @pulumi.getter(name="applyToAllCustomEnvironments")
    def apply_to_all_custom_environments(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the shared environment variable should be applied to all custom environments in the linked projects.
        """
        return pulumi.get(self, "apply_to_all_custom_environments")

    @apply_to_all_custom_environments.setter
    def apply_to_all_custom_environments(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "apply_to_all_custom_environments", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A comment explaining what the environment variable is for.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    def sensitive(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        """
        return pulumi.get(self, "sensitive")

    @sensitive.setter
    def sensitive(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sensitive", value)

    @_builtins.property
    @pulumi.getter
    def targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`.
        """
        return pulumi.get(self, "targets")

    @targets.setter
    def targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "targets", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Vercel team. Shared environment variables require a team.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter(name="valueWo")
    def value_wo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        return pulumi.get(self, "value_wo")

    @value_wo.setter
    def value_wo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value_wo", value)


@pulumi.input_type
class _SharedEnvironmentVariableState:
    def __init__(__self__, *,
                 apply_to_all_custom_environments: Optional[pulumi.Input[_builtins.bool]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 sensitive: Optional[pulumi.Input[_builtins.bool]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_wo: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SharedEnvironmentVariable resources.
        :param pulumi.Input[_builtins.bool] apply_to_all_custom_environments: Whether the shared environment variable should be applied to all custom environments in the linked projects.
        :param pulumi.Input[_builtins.str] comment: A comment explaining what the environment variable is for.
        :param pulumi.Input[_builtins.str] key: The name of the Environment Variable.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] project_ids: The ID of the Vercel project.
        :param pulumi.Input[_builtins.bool] sensitive: Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] targets: The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team. Shared environment variables require a team.
        :param pulumi.Input[_builtins.str] value: (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        :param pulumi.Input[_builtins.str] value_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
               (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        if apply_to_all_custom_environments is not None:
            pulumi.set(__self__, "apply_to_all_custom_environments", apply_to_all_custom_environments)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if project_ids is not None:
            pulumi.set(__self__, "project_ids", project_ids)
        if sensitive is not None:
            pulumi.set(__self__, "sensitive", sensitive)
        if targets is not None:
            pulumi.set(__self__, "targets", targets)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if value_wo is not None:
            pulumi.set(__self__, "value_wo", value_wo)

    @_builtins.property
    @pulumi.getter(name="applyToAllCustomEnvironments")
    def apply_to_all_custom_environments(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the shared environment variable should be applied to all custom environments in the linked projects.
        """
        return pulumi.get(self, "apply_to_all_custom_environments")

    @apply_to_all_custom_environments.setter
    def apply_to_all_custom_environments(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "apply_to_all_custom_environments", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A comment explaining what the environment variable is for.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Environment Variable.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="projectIds")
    def project_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The ID of the Vercel project.
        """
        return pulumi.get(self, "project_ids")

    @project_ids.setter
    def project_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "project_ids", value)

    @_builtins.property
    @pulumi.getter
    def sensitive(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        """
        return pulumi.get(self, "sensitive")

    @sensitive.setter
    def sensitive(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sensitive", value)

    @_builtins.property
    @pulumi.getter
    def targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`.
        """
        return pulumi.get(self, "targets")

    @targets.setter
    def targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "targets", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Vercel team. Shared environment variables require a team.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter(name="valueWo")
    def value_wo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        return pulumi.get(self, "value_wo")

    @value_wo.setter
    def value_wo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value_wo", value)


@pulumi.type_token("vercel:index/sharedEnvironmentVariable:SharedEnvironmentVariable")
class SharedEnvironmentVariable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 apply_to_all_custom_environments: Optional[pulumi.Input[_builtins.bool]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 sensitive: Optional[pulumi.Input[_builtins.bool]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_wo: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        example = vercel.Project("example",
            name="example",
            git_repository={
                "type": "github",
                "repo": "vercel/some-repo",
            })
        # A shared environment variable that will be created
        # and associated with the "example" project.
        example_shared_environment_variable = vercel.SharedEnvironmentVariable("example",
            key="EXAMPLE",
            value="some_value",
            targets=["production"],
            comment="an example shared variable",
            project_ids=[example.id])
        ```

        ## Import

        You can import via the team_id and environment variable id.

        - team_id can be found in the team `settings` tab in the Vercel UI.

        - environment variable id can be taken from the network tab inside developer tools, while you are on the project page.

        Note also, that the value field for sensitive environment variables will be imported as `null`.

        ```sh
        $ pulumi import vercel:index/sharedEnvironmentVariable:SharedEnvironmentVariable example team_xxxxxxxxxxxxxxxxxxxxxxxx/env_yyyyyyyyyyyyy
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] apply_to_all_custom_environments: Whether the shared environment variable should be applied to all custom environments in the linked projects.
        :param pulumi.Input[_builtins.str] comment: A comment explaining what the environment variable is for.
        :param pulumi.Input[_builtins.str] key: The name of the Environment Variable.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] project_ids: The ID of the Vercel project.
        :param pulumi.Input[_builtins.bool] sensitive: Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] targets: The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team. Shared environment variables require a team.
        :param pulumi.Input[_builtins.str] value: (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        :param pulumi.Input[_builtins.str] value_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
               (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SharedEnvironmentVariableArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        example = vercel.Project("example",
            name="example",
            git_repository={
                "type": "github",
                "repo": "vercel/some-repo",
            })
        # A shared environment variable that will be created
        # and associated with the "example" project.
        example_shared_environment_variable = vercel.SharedEnvironmentVariable("example",
            key="EXAMPLE",
            value="some_value",
            targets=["production"],
            comment="an example shared variable",
            project_ids=[example.id])
        ```

        ## Import

        You can import via the team_id and environment variable id.

        - team_id can be found in the team `settings` tab in the Vercel UI.

        - environment variable id can be taken from the network tab inside developer tools, while you are on the project page.

        Note also, that the value field for sensitive environment variables will be imported as `null`.

        ```sh
        $ pulumi import vercel:index/sharedEnvironmentVariable:SharedEnvironmentVariable example team_xxxxxxxxxxxxxxxxxxxxxxxx/env_yyyyyyyyyyyyy
        ```

        :param str resource_name: The name of the resource.
        :param SharedEnvironmentVariableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SharedEnvironmentVariableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 apply_to_all_custom_environments: Optional[pulumi.Input[_builtins.bool]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 sensitive: Optional[pulumi.Input[_builtins.bool]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_wo: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SharedEnvironmentVariableArgs.__new__(SharedEnvironmentVariableArgs)

            __props__.__dict__["apply_to_all_custom_environments"] = apply_to_all_custom_environments
            __props__.__dict__["comment"] = comment
            if key is None and not opts.urn:
                raise TypeError("Missing required property 'key'")
            __props__.__dict__["key"] = key
            if project_ids is None and not opts.urn:
                raise TypeError("Missing required property 'project_ids'")
            __props__.__dict__["project_ids"] = project_ids
            __props__.__dict__["sensitive"] = sensitive
            __props__.__dict__["targets"] = targets
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["value"] = None if value is None else pulumi.Output.secret(value)
            __props__.__dict__["value_wo"] = None if value_wo is None else pulumi.Output.secret(value_wo)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["value", "valueWo"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SharedEnvironmentVariable, __self__).__init__(
            'vercel:index/sharedEnvironmentVariable:SharedEnvironmentVariable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            apply_to_all_custom_environments: Optional[pulumi.Input[_builtins.bool]] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            key: Optional[pulumi.Input[_builtins.str]] = None,
            project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            sensitive: Optional[pulumi.Input[_builtins.bool]] = None,
            targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None,
            value_wo: Optional[pulumi.Input[_builtins.str]] = None) -> 'SharedEnvironmentVariable':
        """
        Get an existing SharedEnvironmentVariable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] apply_to_all_custom_environments: Whether the shared environment variable should be applied to all custom environments in the linked projects.
        :param pulumi.Input[_builtins.str] comment: A comment explaining what the environment variable is for.
        :param pulumi.Input[_builtins.str] key: The name of the Environment Variable.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] project_ids: The ID of the Vercel project.
        :param pulumi.Input[_builtins.bool] sensitive: Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] targets: The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team. Shared environment variables require a team.
        :param pulumi.Input[_builtins.str] value: (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        :param pulumi.Input[_builtins.str] value_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
               (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SharedEnvironmentVariableState.__new__(_SharedEnvironmentVariableState)

        __props__.__dict__["apply_to_all_custom_environments"] = apply_to_all_custom_environments
        __props__.__dict__["comment"] = comment
        __props__.__dict__["key"] = key
        __props__.__dict__["project_ids"] = project_ids
        __props__.__dict__["sensitive"] = sensitive
        __props__.__dict__["targets"] = targets
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["value"] = value
        __props__.__dict__["value_wo"] = value_wo
        return SharedEnvironmentVariable(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="applyToAllCustomEnvironments")
    def apply_to_all_custom_environments(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the shared environment variable should be applied to all custom environments in the linked projects.
        """
        return pulumi.get(self, "apply_to_all_custom_environments")

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[_builtins.str]:
        """
        A comment explaining what the environment variable is for.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Environment Variable.
        """
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter(name="projectIds")
    def project_ids(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The ID of the Vercel project.
        """
        return pulumi.get(self, "project_ids")

    @_builtins.property
    @pulumi.getter
    def sensitive(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        """
        return pulumi.get(self, "sensitive")

    @_builtins.property
    @pulumi.getter
    def targets(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`.
        """
        return pulumi.get(self, "targets")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Vercel team. Shared environment variables require a team.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter(name="valueWo")
    def value_wo(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        return pulumi.get(self, "value_wo")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TeamMemberArgs', 'TeamMember']

@pulumi.input_type
class TeamMemberArgs:
    def __init__(__self__, *,
                 role: pulumi.Input[_builtins.str],
                 team_id: pulumi.Input[_builtins.str],
                 access_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 projects: Optional[pulumi.Input[Sequence[pulumi.Input['TeamMemberProjectArgs']]]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a TeamMember resource.
        :param pulumi.Input[_builtins.str] role: The role that the user should have in the team. One of 'MEMBER', 'OWNER', 'VIEWER', 'VIEWER*FOR*PLUS', 'DEVELOPER', 'BILLING', 'SECURITY', or 'CONTRIBUTOR'. Depending on your Team's plan, some of these roles may be unavailable.
        :param pulumi.Input[_builtins.str] team_id: The ID of the existing Vercel Team.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] access_groups: If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of access groups IDs that the user should be granted access to.
        :param pulumi.Input[_builtins.str] email: The email of the user to add to the team. Must specify one of user_id or email.
        :param pulumi.Input[Sequence[pulumi.Input['TeamMemberProjectArgs']]] projects: If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of projects that the user should be granted access to, along with their role in each project.
        :param pulumi.Input[_builtins.str] user_id: The ID of the user to add to the team. Must specify one of user_id or email.
        """
        pulumi.set(__self__, "role", role)
        pulumi.set(__self__, "team_id", team_id)
        if access_groups is not None:
            pulumi.set(__self__, "access_groups", access_groups)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if projects is not None:
            pulumi.set(__self__, "projects", projects)
        if user_id is not None:
            warnings.warn("""Users can no longer be added to a team by their user_id. This field is maintained purely for backwards compatibility.""", DeprecationWarning)
            pulumi.log.warn("""user_id is deprecated: Users can no longer be added to a team by their user_id. This field is maintained purely for backwards compatibility.""")
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter
    def role(self) -> pulumi.Input[_builtins.str]:
        """
        The role that the user should have in the team. One of 'MEMBER', 'OWNER', 'VIEWER', 'VIEWER*FOR*PLUS', 'DEVELOPER', 'BILLING', 'SECURITY', or 'CONTRIBUTOR'. Depending on your Team's plan, some of these roles may be unavailable.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "role", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the existing Vercel Team.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter(name="accessGroups")
    def access_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of access groups IDs that the user should be granted access to.
        """
        return pulumi.get(self, "access_groups")

    @access_groups.setter
    def access_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "access_groups", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The email of the user to add to the team. Must specify one of user_id or email.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter
    def projects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TeamMemberProjectArgs']]]]:
        """
        If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of projects that the user should be granted access to, along with their role in each project.
        """
        return pulumi.get(self, "projects")

    @projects.setter
    def projects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TeamMemberProjectArgs']]]]):
        pulumi.set(self, "projects", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    @_utilities.deprecated("""Users can no longer be added to a team by their user_id. This field is maintained purely for backwards compatibility.""")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the user to add to the team. Must specify one of user_id or email.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _TeamMemberState:
    def __init__(__self__, *,
                 access_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 confirmed: Optional[pulumi.Input[_builtins.bool]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 projects: Optional[pulumi.Input[Sequence[pulumi.Input['TeamMemberProjectArgs']]]] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering TeamMember resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] access_groups: If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of access groups IDs that the user should be granted access to.
        :param pulumi.Input[_builtins.bool] confirmed: Whether the user has confirmed their invitation.
        :param pulumi.Input[_builtins.str] email: The email of the user to add to the team. Must specify one of user_id or email.
        :param pulumi.Input[Sequence[pulumi.Input['TeamMemberProjectArgs']]] projects: If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of projects that the user should be granted access to, along with their role in each project.
        :param pulumi.Input[_builtins.str] role: The role that the user should have in the team. One of 'MEMBER', 'OWNER', 'VIEWER', 'VIEWER*FOR*PLUS', 'DEVELOPER', 'BILLING', 'SECURITY', or 'CONTRIBUTOR'. Depending on your Team's plan, some of these roles may be unavailable.
        :param pulumi.Input[_builtins.str] team_id: The ID of the existing Vercel Team.
        :param pulumi.Input[_builtins.str] user_id: The ID of the user to add to the team. Must specify one of user_id or email.
        """
        if access_groups is not None:
            pulumi.set(__self__, "access_groups", access_groups)
        if confirmed is not None:
            pulumi.set(__self__, "confirmed", confirmed)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if projects is not None:
            pulumi.set(__self__, "projects", projects)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if user_id is not None:
            warnings.warn("""Users can no longer be added to a team by their user_id. This field is maintained purely for backwards compatibility.""", DeprecationWarning)
            pulumi.log.warn("""user_id is deprecated: Users can no longer be added to a team by their user_id. This field is maintained purely for backwards compatibility.""")
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="accessGroups")
    def access_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of access groups IDs that the user should be granted access to.
        """
        return pulumi.get(self, "access_groups")

    @access_groups.setter
    def access_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "access_groups", value)

    @_builtins.property
    @pulumi.getter
    def confirmed(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the user has confirmed their invitation.
        """
        return pulumi.get(self, "confirmed")

    @confirmed.setter
    def confirmed(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "confirmed", value)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The email of the user to add to the team. Must specify one of user_id or email.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter
    def projects(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TeamMemberProjectArgs']]]]:
        """
        If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of projects that the user should be granted access to, along with their role in each project.
        """
        return pulumi.get(self, "projects")

    @projects.setter
    def projects(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TeamMemberProjectArgs']]]]):
        pulumi.set(self, "projects", value)

    @_builtins.property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The role that the user should have in the team. One of 'MEMBER', 'OWNER', 'VIEWER', 'VIEWER*FOR*PLUS', 'DEVELOPER', 'BILLING', 'SECURITY', or 'CONTRIBUTOR'. Depending on your Team's plan, some of these roles may be unavailable.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the existing Vercel Team.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    @_utilities.deprecated("""Users can no longer be added to a team by their user_id. This field is maintained purely for backwards compatibility.""")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the user to add to the team. Must specify one of user_id or email.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("vercel:index/teamMember:TeamMember")
class TeamMember(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 projects: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamMemberProjectArgs', 'TeamMemberProjectArgsDict']]]]] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provider a resource for managing a team member.

        > **Note:** Users can no longer be added to a team by their user_id. This field is maintained purely for backwards compatibility.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        # Recommended: Use email to add team members
        example = vercel.TeamMember("example",
            team_id="team_xxxxxxxxxxxxxxxxxxxxxxxx",
            email="example@example.com",
            role="MEMBER")
        ```

        ## Import

        To import, use the team_id and user_id.

        ```sh
        $ pulumi import vercel:index/teamMember:TeamMember example team_xxxxxxxxxxxxxxxxxxxxxxxx/uuuuuuuuuuuuuuuuuuuuuuuuuu
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] access_groups: If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of access groups IDs that the user should be granted access to.
        :param pulumi.Input[_builtins.str] email: The email of the user to add to the team. Must specify one of user_id or email.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TeamMemberProjectArgs', 'TeamMemberProjectArgsDict']]]] projects: If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of projects that the user should be granted access to, along with their role in each project.
        :param pulumi.Input[_builtins.str] role: The role that the user should have in the team. One of 'MEMBER', 'OWNER', 'VIEWER', 'VIEWER*FOR*PLUS', 'DEVELOPER', 'BILLING', 'SECURITY', or 'CONTRIBUTOR'. Depending on your Team's plan, some of these roles may be unavailable.
        :param pulumi.Input[_builtins.str] team_id: The ID of the existing Vercel Team.
        :param pulumi.Input[_builtins.str] user_id: The ID of the user to add to the team. Must specify one of user_id or email.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TeamMemberArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provider a resource for managing a team member.

        > **Note:** Users can no longer be added to a team by their user_id. This field is maintained purely for backwards compatibility.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        # Recommended: Use email to add team members
        example = vercel.TeamMember("example",
            team_id="team_xxxxxxxxxxxxxxxxxxxxxxxx",
            email="example@example.com",
            role="MEMBER")
        ```

        ## Import

        To import, use the team_id and user_id.

        ```sh
        $ pulumi import vercel:index/teamMember:TeamMember example team_xxxxxxxxxxxxxxxxxxxxxxxx/uuuuuuuuuuuuuuuuuuuuuuuuuu
        ```

        :param str resource_name: The name of the resource.
        :param TeamMemberArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TeamMemberArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 projects: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamMemberProjectArgs', 'TeamMemberProjectArgsDict']]]]] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TeamMemberArgs.__new__(TeamMemberArgs)

            __props__.__dict__["access_groups"] = access_groups
            __props__.__dict__["email"] = email
            __props__.__dict__["projects"] = projects
            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
            if team_id is None and not opts.urn:
                raise TypeError("Missing required property 'team_id'")
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["confirmed"] = None
        super(TeamMember, __self__).__init__(
            'vercel:index/teamMember:TeamMember',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            confirmed: Optional[pulumi.Input[_builtins.bool]] = None,
            email: Optional[pulumi.Input[_builtins.str]] = None,
            projects: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TeamMemberProjectArgs', 'TeamMemberProjectArgsDict']]]]] = None,
            role: Optional[pulumi.Input[_builtins.str]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'TeamMember':
        """
        Get an existing TeamMember resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] access_groups: If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of access groups IDs that the user should be granted access to.
        :param pulumi.Input[_builtins.bool] confirmed: Whether the user has confirmed their invitation.
        :param pulumi.Input[_builtins.str] email: The email of the user to add to the team. Must specify one of user_id or email.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TeamMemberProjectArgs', 'TeamMemberProjectArgsDict']]]] projects: If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of projects that the user should be granted access to, along with their role in each project.
        :param pulumi.Input[_builtins.str] role: The role that the user should have in the team. One of 'MEMBER', 'OWNER', 'VIEWER', 'VIEWER*FOR*PLUS', 'DEVELOPER', 'BILLING', 'SECURITY', or 'CONTRIBUTOR'. Depending on your Team's plan, some of these roles may be unavailable.
        :param pulumi.Input[_builtins.str] team_id: The ID of the existing Vercel Team.
        :param pulumi.Input[_builtins.str] user_id: The ID of the user to add to the team. Must specify one of user_id or email.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TeamMemberState.__new__(_TeamMemberState)

        __props__.__dict__["access_groups"] = access_groups
        __props__.__dict__["confirmed"] = confirmed
        __props__.__dict__["email"] = email
        __props__.__dict__["projects"] = projects
        __props__.__dict__["role"] = role
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["user_id"] = user_id
        return TeamMember(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessGroups")
    def access_groups(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of access groups IDs that the user should be granted access to.
        """
        return pulumi.get(self, "access_groups")

    @_builtins.property
    @pulumi.getter
    def confirmed(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the user has confirmed their invitation.
        """
        return pulumi.get(self, "confirmed")

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Output[_builtins.str]:
        """
        The email of the user to add to the team. Must specify one of user_id or email.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter
    def projects(self) -> pulumi.Output[Optional[Sequence['outputs.TeamMemberProject']]]:
        """
        If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of projects that the user should be granted access to, along with their role in each project.
        """
        return pulumi.get(self, "projects")

    @_builtins.property
    @pulumi.getter
    def role(self) -> pulumi.Output[_builtins.str]:
        """
        The role that the user should have in the team. One of 'MEMBER', 'OWNER', 'VIEWER', 'VIEWER*FOR*PLUS', 'DEVELOPER', 'BILLING', 'SECURITY', or 'CONTRIBUTOR'. Depending on your Team's plan, some of these roles may be unavailable.
        """
        return pulumi.get(self, "role")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the existing Vercel Team.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter(name="userId")
    @_utilities.deprecated("""Users can no longer be added to a team by their user_id. This field is maintained purely for backwards compatibility.""")
    def user_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the user to add to the team. Must specify one of user_id or email.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TeamConfigArgs', 'TeamConfig']

@pulumi.input_type
class TeamConfigArgs:
    def __init__(__self__, *,
                 avatar: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_preview_feedback: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_production_feedback: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_ip_addresses: Optional[pulumi.Input[_builtins.bool]] = None,
                 hide_ip_addresses_in_log_drains: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 preview_deployment_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_caching: Optional[pulumi.Input['TeamConfigRemoteCachingArgs']] = None,
                 saml: Optional[pulumi.Input['TeamConfigSamlArgs']] = None,
                 sensitive_environment_variable_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 slug: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a TeamConfig resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] avatar: The `avatar` should be a the 'file' attribute from a get_file data source.
        :param pulumi.Input[_builtins.str] description: A description of the team.
        :param pulumi.Input[_builtins.str] email_domain: Hostname that'll be matched with emails on sign-up to automatically join the Team.
        :param pulumi.Input[_builtins.str] enable_preview_feedback: Enables the Vercel Toolbar on your preview deployments: one of on, off or default.
        :param pulumi.Input[_builtins.str] enable_production_feedback: Enables the Vercel Toolbar on your production deployments: one of on, off or default.
        :param pulumi.Input[_builtins.bool] hide_ip_addresses: Indicates if ip addresses should be accessible in o11y tooling.
        :param pulumi.Input[_builtins.bool] hide_ip_addresses_in_log_drains: Indicates if ip addresses should be accessible in log drains.
        :param pulumi.Input[_builtins.str] name: The name of the team.
        :param pulumi.Input[_builtins.str] preview_deployment_suffix: The hostname that is used as the preview deployment suffix.
        :param pulumi.Input['TeamConfigRemoteCachingArgs'] remote_caching: Configuration for Remote Caching.
        :param pulumi.Input['TeamConfigSamlArgs'] saml: Configuration for SAML authentication.
        :param pulumi.Input[_builtins.str] sensitive_environment_variable_policy: Ensures that all environment variables created by members of this team will be created as Sensitive Environment Variables which can only be decrypted by Vercel's deployment system.: one of on, off or default.
        :param pulumi.Input[_builtins.str] slug: The slug of the team. Will be used in the URL of the team's dashboard.
        """
        if avatar is not None:
            pulumi.set(__self__, "avatar", avatar)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email_domain is not None:
            pulumi.set(__self__, "email_domain", email_domain)
        if enable_preview_feedback is not None:
            pulumi.set(__self__, "enable_preview_feedback", enable_preview_feedback)
        if enable_production_feedback is not None:
            pulumi.set(__self__, "enable_production_feedback", enable_production_feedback)
        if hide_ip_addresses is not None:
            pulumi.set(__self__, "hide_ip_addresses", hide_ip_addresses)
        if hide_ip_addresses_in_log_drains is not None:
            pulumi.set(__self__, "hide_ip_addresses_in_log_drains", hide_ip_addresses_in_log_drains)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if preview_deployment_suffix is not None:
            pulumi.set(__self__, "preview_deployment_suffix", preview_deployment_suffix)
        if remote_caching is not None:
            pulumi.set(__self__, "remote_caching", remote_caching)
        if saml is not None:
            pulumi.set(__self__, "saml", saml)
        if sensitive_environment_variable_policy is not None:
            pulumi.set(__self__, "sensitive_environment_variable_policy", sensitive_environment_variable_policy)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)

    @_builtins.property
    @pulumi.getter
    def avatar(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The `avatar` should be a the 'file' attribute from a get_file data source.
        """
        return pulumi.get(self, "avatar")

    @avatar.setter
    def avatar(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "avatar", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description of the team.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="emailDomain")
    def email_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hostname that'll be matched with emails on sign-up to automatically join the Team.
        """
        return pulumi.get(self, "email_domain")

    @email_domain.setter
    def email_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email_domain", value)

    @_builtins.property
    @pulumi.getter(name="enablePreviewFeedback")
    def enable_preview_feedback(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables the Vercel Toolbar on your preview deployments: one of on, off or default.
        """
        return pulumi.get(self, "enable_preview_feedback")

    @enable_preview_feedback.setter
    def enable_preview_feedback(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "enable_preview_feedback", value)

    @_builtins.property
    @pulumi.getter(name="enableProductionFeedback")
    def enable_production_feedback(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables the Vercel Toolbar on your production deployments: one of on, off or default.
        """
        return pulumi.get(self, "enable_production_feedback")

    @enable_production_feedback.setter
    def enable_production_feedback(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "enable_production_feedback", value)

    @_builtins.property
    @pulumi.getter(name="hideIpAddresses")
    def hide_ip_addresses(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if ip addresses should be accessible in o11y tooling.
        """
        return pulumi.get(self, "hide_ip_addresses")

    @hide_ip_addresses.setter
    def hide_ip_addresses(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hide_ip_addresses", value)

    @_builtins.property
    @pulumi.getter(name="hideIpAddressesInLogDrains")
    def hide_ip_addresses_in_log_drains(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if ip addresses should be accessible in log drains.
        """
        return pulumi.get(self, "hide_ip_addresses_in_log_drains")

    @hide_ip_addresses_in_log_drains.setter
    def hide_ip_addresses_in_log_drains(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hide_ip_addresses_in_log_drains", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the team.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="previewDeploymentSuffix")
    def preview_deployment_suffix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hostname that is used as the preview deployment suffix.
        """
        return pulumi.get(self, "preview_deployment_suffix")

    @preview_deployment_suffix.setter
    def preview_deployment_suffix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "preview_deployment_suffix", value)

    @_builtins.property
    @pulumi.getter(name="remoteCaching")
    def remote_caching(self) -> Optional[pulumi.Input['TeamConfigRemoteCachingArgs']]:
        """
        Configuration for Remote Caching.
        """
        return pulumi.get(self, "remote_caching")

    @remote_caching.setter
    def remote_caching(self, value: Optional[pulumi.Input['TeamConfigRemoteCachingArgs']]):
        pulumi.set(self, "remote_caching", value)

    @_builtins.property
    @pulumi.getter
    def saml(self) -> Optional[pulumi.Input['TeamConfigSamlArgs']]:
        """
        Configuration for SAML authentication.
        """
        return pulumi.get(self, "saml")

    @saml.setter
    def saml(self, value: Optional[pulumi.Input['TeamConfigSamlArgs']]):
        pulumi.set(self, "saml", value)

    @_builtins.property
    @pulumi.getter(name="sensitiveEnvironmentVariablePolicy")
    def sensitive_environment_variable_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Ensures that all environment variables created by members of this team will be created as Sensitive Environment Variables which can only be decrypted by Vercel's deployment system.: one of on, off or default.
        """
        return pulumi.get(self, "sensitive_environment_variable_policy")

    @sensitive_environment_variable_policy.setter
    def sensitive_environment_variable_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sensitive_environment_variable_policy", value)

    @_builtins.property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The slug of the team. Will be used in the URL of the team's dashboard.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slug", value)


@pulumi.input_type
class _TeamConfigState:
    def __init__(__self__, *,
                 avatar: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_preview_feedback: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_production_feedback: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_ip_addresses: Optional[pulumi.Input[_builtins.bool]] = None,
                 hide_ip_addresses_in_log_drains: Optional[pulumi.Input[_builtins.bool]] = None,
                 invite_code: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 preview_deployment_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_caching: Optional[pulumi.Input['TeamConfigRemoteCachingArgs']] = None,
                 saml: Optional[pulumi.Input['TeamConfigSamlArgs']] = None,
                 sensitive_environment_variable_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 slug: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering TeamConfig resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] avatar: The `avatar` should be a the 'file' attribute from a get_file data source.
        :param pulumi.Input[_builtins.str] description: A description of the team.
        :param pulumi.Input[_builtins.str] email_domain: Hostname that'll be matched with emails on sign-up to automatically join the Team.
        :param pulumi.Input[_builtins.str] enable_preview_feedback: Enables the Vercel Toolbar on your preview deployments: one of on, off or default.
        :param pulumi.Input[_builtins.str] enable_production_feedback: Enables the Vercel Toolbar on your production deployments: one of on, off or default.
        :param pulumi.Input[_builtins.bool] hide_ip_addresses: Indicates if ip addresses should be accessible in o11y tooling.
        :param pulumi.Input[_builtins.bool] hide_ip_addresses_in_log_drains: Indicates if ip addresses should be accessible in log drains.
        :param pulumi.Input[_builtins.str] invite_code: A code that can be used to join this team. Only visible to Team owners.
        :param pulumi.Input[_builtins.str] name: The name of the team.
        :param pulumi.Input[_builtins.str] preview_deployment_suffix: The hostname that is used as the preview deployment suffix.
        :param pulumi.Input['TeamConfigRemoteCachingArgs'] remote_caching: Configuration for Remote Caching.
        :param pulumi.Input['TeamConfigSamlArgs'] saml: Configuration for SAML authentication.
        :param pulumi.Input[_builtins.str] sensitive_environment_variable_policy: Ensures that all environment variables created by members of this team will be created as Sensitive Environment Variables which can only be decrypted by Vercel's deployment system.: one of on, off or default.
        :param pulumi.Input[_builtins.str] slug: The slug of the team. Will be used in the URL of the team's dashboard.
        """
        if avatar is not None:
            pulumi.set(__self__, "avatar", avatar)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if email_domain is not None:
            pulumi.set(__self__, "email_domain", email_domain)
        if enable_preview_feedback is not None:
            pulumi.set(__self__, "enable_preview_feedback", enable_preview_feedback)
        if enable_production_feedback is not None:
            pulumi.set(__self__, "enable_production_feedback", enable_production_feedback)
        if hide_ip_addresses is not None:
            pulumi.set(__self__, "hide_ip_addresses", hide_ip_addresses)
        if hide_ip_addresses_in_log_drains is not None:
            pulumi.set(__self__, "hide_ip_addresses_in_log_drains", hide_ip_addresses_in_log_drains)
        if invite_code is not None:
            pulumi.set(__self__, "invite_code", invite_code)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if preview_deployment_suffix is not None:
            pulumi.set(__self__, "preview_deployment_suffix", preview_deployment_suffix)
        if remote_caching is not None:
            pulumi.set(__self__, "remote_caching", remote_caching)
        if saml is not None:
            pulumi.set(__self__, "saml", saml)
        if sensitive_environment_variable_policy is not None:
            pulumi.set(__self__, "sensitive_environment_variable_policy", sensitive_environment_variable_policy)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)

    @_builtins.property
    @pulumi.getter
    def avatar(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The `avatar` should be a the 'file' attribute from a get_file data source.
        """
        return pulumi.get(self, "avatar")

    @avatar.setter
    def avatar(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "avatar", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description of the team.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="emailDomain")
    def email_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Hostname that'll be matched with emails on sign-up to automatically join the Team.
        """
        return pulumi.get(self, "email_domain")

    @email_domain.setter
    def email_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email_domain", value)

    @_builtins.property
    @pulumi.getter(name="enablePreviewFeedback")
    def enable_preview_feedback(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables the Vercel Toolbar on your preview deployments: one of on, off or default.
        """
        return pulumi.get(self, "enable_preview_feedback")

    @enable_preview_feedback.setter
    def enable_preview_feedback(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "enable_preview_feedback", value)

    @_builtins.property
    @pulumi.getter(name="enableProductionFeedback")
    def enable_production_feedback(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Enables the Vercel Toolbar on your production deployments: one of on, off or default.
        """
        return pulumi.get(self, "enable_production_feedback")

    @enable_production_feedback.setter
    def enable_production_feedback(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "enable_production_feedback", value)

    @_builtins.property
    @pulumi.getter(name="hideIpAddresses")
    def hide_ip_addresses(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if ip addresses should be accessible in o11y tooling.
        """
        return pulumi.get(self, "hide_ip_addresses")

    @hide_ip_addresses.setter
    def hide_ip_addresses(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hide_ip_addresses", value)

    @_builtins.property
    @pulumi.getter(name="hideIpAddressesInLogDrains")
    def hide_ip_addresses_in_log_drains(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if ip addresses should be accessible in log drains.
        """
        return pulumi.get(self, "hide_ip_addresses_in_log_drains")

    @hide_ip_addresses_in_log_drains.setter
    def hide_ip_addresses_in_log_drains(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "hide_ip_addresses_in_log_drains", value)

    @_builtins.property
    @pulumi.getter(name="inviteCode")
    def invite_code(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A code that can be used to join this team. Only visible to Team owners.
        """
        return pulumi.get(self, "invite_code")

    @invite_code.setter
    def invite_code(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "invite_code", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the team.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="previewDeploymentSuffix")
    def preview_deployment_suffix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hostname that is used as the preview deployment suffix.
        """
        return pulumi.get(self, "preview_deployment_suffix")

    @preview_deployment_suffix.setter
    def preview_deployment_suffix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "preview_deployment_suffix", value)

    @_builtins.property
    @pulumi.getter(name="remoteCaching")
    def remote_caching(self) -> Optional[pulumi.Input['TeamConfigRemoteCachingArgs']]:
        """
        Configuration for Remote Caching.
        """
        return pulumi.get(self, "remote_caching")

    @remote_caching.setter
    def remote_caching(self, value: Optional[pulumi.Input['TeamConfigRemoteCachingArgs']]):
        pulumi.set(self, "remote_caching", value)

    @_builtins.property
    @pulumi.getter
    def saml(self) -> Optional[pulumi.Input['TeamConfigSamlArgs']]:
        """
        Configuration for SAML authentication.
        """
        return pulumi.get(self, "saml")

    @saml.setter
    def saml(self, value: Optional[pulumi.Input['TeamConfigSamlArgs']]):
        pulumi.set(self, "saml", value)

    @_builtins.property
    @pulumi.getter(name="sensitiveEnvironmentVariablePolicy")
    def sensitive_environment_variable_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Ensures that all environment variables created by members of this team will be created as Sensitive Environment Variables which can only be decrypted by Vercel's deployment system.: one of on, off or default.
        """
        return pulumi.get(self, "sensitive_environment_variable_policy")

    @sensitive_environment_variable_policy.setter
    def sensitive_environment_variable_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sensitive_environment_variable_policy", value)

    @_builtins.property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The slug of the team. Will be used in the URL of the team's dashboard.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slug", value)


@pulumi.type_token("vercel:index/teamConfig:TeamConfig")
class TeamConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 avatar: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_preview_feedback: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_production_feedback: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_ip_addresses: Optional[pulumi.Input[_builtins.bool]] = None,
                 hide_ip_addresses_in_log_drains: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 preview_deployment_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_caching: Optional[pulumi.Input[Union['TeamConfigRemoteCachingArgs', 'TeamConfigRemoteCachingArgsDict']]] = None,
                 saml: Optional[pulumi.Input[Union['TeamConfigSamlArgs', 'TeamConfigSamlArgsDict']]] = None,
                 sensitive_environment_variable_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 slug: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages the configuration of an existing Vercel Team.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vercel as vercel
        import pulumiverse_vercel as vercel

        example = vercel.get_file(path="example/avatar.png")
        example_team_config = vercel.TeamConfig("example",
            id="team_xxxxxxxxxxxxxxxxxxxxxxxx",
            avatar=example.file,
            name="Vercel terraform example",
            slug="vercel-terraform-example",
            description="Vercel Terraform Example",
            sensitive_environment_variable_policy="off",
            remote_caching={
                "enabled": True,
            },
            enable_preview_feedback="off",
            enable_production_feedback="off",
            hide_ip_addresses=True,
            hide_ip_addresses_in_log_drains=True)
        ```

        ## Import

        Team config can be imported via the team ID.

        - team_id can be found in the team `settings` tab in the Vercel UI.

        ```sh
        $ pulumi import vercel:index/teamConfig:TeamConfig example team_xxxxxxxxxxxxxxxxxxxxxxxx
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] avatar: The `avatar` should be a the 'file' attribute from a get_file data source.
        :param pulumi.Input[_builtins.str] description: A description of the team.
        :param pulumi.Input[_builtins.str] email_domain: Hostname that'll be matched with emails on sign-up to automatically join the Team.
        :param pulumi.Input[_builtins.str] enable_preview_feedback: Enables the Vercel Toolbar on your preview deployments: one of on, off or default.
        :param pulumi.Input[_builtins.str] enable_production_feedback: Enables the Vercel Toolbar on your production deployments: one of on, off or default.
        :param pulumi.Input[_builtins.bool] hide_ip_addresses: Indicates if ip addresses should be accessible in o11y tooling.
        :param pulumi.Input[_builtins.bool] hide_ip_addresses_in_log_drains: Indicates if ip addresses should be accessible in log drains.
        :param pulumi.Input[_builtins.str] name: The name of the team.
        :param pulumi.Input[_builtins.str] preview_deployment_suffix: The hostname that is used as the preview deployment suffix.
        :param pulumi.Input[Union['TeamConfigRemoteCachingArgs', 'TeamConfigRemoteCachingArgsDict']] remote_caching: Configuration for Remote Caching.
        :param pulumi.Input[Union['TeamConfigSamlArgs', 'TeamConfigSamlArgsDict']] saml: Configuration for SAML authentication.
        :param pulumi.Input[_builtins.str] sensitive_environment_variable_policy: Ensures that all environment variables created by members of this team will be created as Sensitive Environment Variables which can only be decrypted by Vercel's deployment system.: one of on, off or default.
        :param pulumi.Input[_builtins.str] slug: The slug of the team. Will be used in the URL of the team's dashboard.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[TeamConfigArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages the configuration of an existing Vercel Team.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_vercel as vercel
        import pulumiverse_vercel as vercel

        example = vercel.get_file(path="example/avatar.png")
        example_team_config = vercel.TeamConfig("example",
            id="team_xxxxxxxxxxxxxxxxxxxxxxxx",
            avatar=example.file,
            name="Vercel terraform example",
            slug="vercel-terraform-example",
            description="Vercel Terraform Example",
            sensitive_environment_variable_policy="off",
            remote_caching={
                "enabled": True,
            },
            enable_preview_feedback="off",
            enable_production_feedback="off",
            hide_ip_addresses=True,
            hide_ip_addresses_in_log_drains=True)
        ```

        ## Import

        Team config can be imported via the team ID.

        - team_id can be found in the team `settings` tab in the Vercel UI.

        ```sh
        $ pulumi import vercel:index/teamConfig:TeamConfig example team_xxxxxxxxxxxxxxxxxxxxxxxx
        ```

        :param str resource_name: The name of the resource.
        :param TeamConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TeamConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 avatar: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 email_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_preview_feedback: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_production_feedback: Optional[pulumi.Input[_builtins.str]] = None,
                 hide_ip_addresses: Optional[pulumi.Input[_builtins.bool]] = None,
                 hide_ip_addresses_in_log_drains: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 preview_deployment_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 remote_caching: Optional[pulumi.Input[Union['TeamConfigRemoteCachingArgs', 'TeamConfigRemoteCachingArgsDict']]] = None,
                 saml: Optional[pulumi.Input[Union['TeamConfigSamlArgs', 'TeamConfigSamlArgsDict']]] = None,
                 sensitive_environment_variable_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 slug: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TeamConfigArgs.__new__(TeamConfigArgs)

            __props__.__dict__["avatar"] = avatar
            __props__.__dict__["description"] = description
            __props__.__dict__["email_domain"] = email_domain
            __props__.__dict__["enable_preview_feedback"] = enable_preview_feedback
            __props__.__dict__["enable_production_feedback"] = enable_production_feedback
            __props__.__dict__["hide_ip_addresses"] = hide_ip_addresses
            __props__.__dict__["hide_ip_addresses_in_log_drains"] = hide_ip_addresses_in_log_drains
            __props__.__dict__["name"] = name
            __props__.__dict__["preview_deployment_suffix"] = preview_deployment_suffix
            __props__.__dict__["remote_caching"] = remote_caching
            __props__.__dict__["saml"] = saml
            __props__.__dict__["sensitive_environment_variable_policy"] = sensitive_environment_variable_policy
            __props__.__dict__["slug"] = slug
            __props__.__dict__["invite_code"] = None
        super(TeamConfig, __self__).__init__(
            'vercel:index/teamConfig:TeamConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            avatar: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            email_domain: Optional[pulumi.Input[_builtins.str]] = None,
            enable_preview_feedback: Optional[pulumi.Input[_builtins.str]] = None,
            enable_production_feedback: Optional[pulumi.Input[_builtins.str]] = None,
            hide_ip_addresses: Optional[pulumi.Input[_builtins.bool]] = None,
            hide_ip_addresses_in_log_drains: Optional[pulumi.Input[_builtins.bool]] = None,
            invite_code: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            preview_deployment_suffix: Optional[pulumi.Input[_builtins.str]] = None,
            remote_caching: Optional[pulumi.Input[Union['TeamConfigRemoteCachingArgs', 'TeamConfigRemoteCachingArgsDict']]] = None,
            saml: Optional[pulumi.Input[Union['TeamConfigSamlArgs', 'TeamConfigSamlArgsDict']]] = None,
            sensitive_environment_variable_policy: Optional[pulumi.Input[_builtins.str]] = None,
            slug: Optional[pulumi.Input[_builtins.str]] = None) -> 'TeamConfig':
        """
        Get an existing TeamConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] avatar: The `avatar` should be a the 'file' attribute from a get_file data source.
        :param pulumi.Input[_builtins.str] description: A description of the team.
        :param pulumi.Input[_builtins.str] email_domain: Hostname that'll be matched with emails on sign-up to automatically join the Team.
        :param pulumi.Input[_builtins.str] enable_preview_feedback: Enables the Vercel Toolbar on your preview deployments: one of on, off or default.
        :param pulumi.Input[_builtins.str] enable_production_feedback: Enables the Vercel Toolbar on your production deployments: one of on, off or default.
        :param pulumi.Input[_builtins.bool] hide_ip_addresses: Indicates if ip addresses should be accessible in o11y tooling.
        :param pulumi.Input[_builtins.bool] hide_ip_addresses_in_log_drains: Indicates if ip addresses should be accessible in log drains.
        :param pulumi.Input[_builtins.str] invite_code: A code that can be used to join this team. Only visible to Team owners.
        :param pulumi.Input[_builtins.str] name: The name of the team.
        :param pulumi.Input[_builtins.str] preview_deployment_suffix: The hostname that is used as the preview deployment suffix.
        :param pulumi.Input[Union['TeamConfigRemoteCachingArgs', 'TeamConfigRemoteCachingArgsDict']] remote_caching: Configuration for Remote Caching.
        :param pulumi.Input[Union['TeamConfigSamlArgs', 'TeamConfigSamlArgsDict']] saml: Configuration for SAML authentication.
        :param pulumi.Input[_builtins.str] sensitive_environment_variable_policy: Ensures that all environment variables created by members of this team will be created as Sensitive Environment Variables which can only be decrypted by Vercel's deployment system.: one of on, off or default.
        :param pulumi.Input[_builtins.str] slug: The slug of the team. Will be used in the URL of the team's dashboard.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TeamConfigState.__new__(_TeamConfigState)

        __props__.__dict__["avatar"] = avatar
        __props__.__dict__["description"] = description
        __props__.__dict__["email_domain"] = email_domain
        __props__.__dict__["enable_preview_feedback"] = enable_preview_feedback
        __props__.__dict__["enable_production_feedback"] = enable_production_feedback
        __props__.__dict__["hide_ip_addresses"] = hide_ip_addresses
        __props__.__dict__["hide_ip_addresses_in_log_drains"] = hide_ip_addresses_in_log_drains
        __props__.__dict__["invite_code"] = invite_code
        __props__.__dict__["name"] = name
        __props__.__dict__["preview_deployment_suffix"] = preview_deployment_suffix
        __props__.__dict__["remote_caching"] = remote_caching
        __props__.__dict__["saml"] = saml
        __props__.__dict__["sensitive_environment_variable_policy"] = sensitive_environment_variable_policy
        __props__.__dict__["slug"] = slug
        return TeamConfig(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def avatar(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        The `avatar` should be a the 'file' attribute from a get_file data source.
        """
        return pulumi.get(self, "avatar")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        A description of the team.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="emailDomain")
    def email_domain(self) -> pulumi.Output[_builtins.str]:
        """
        Hostname that'll be matched with emails on sign-up to automatically join the Team.
        """
        return pulumi.get(self, "email_domain")

    @_builtins.property
    @pulumi.getter(name="enablePreviewFeedback")
    def enable_preview_feedback(self) -> pulumi.Output[_builtins.str]:
        """
        Enables the Vercel Toolbar on your preview deployments: one of on, off or default.
        """
        return pulumi.get(self, "enable_preview_feedback")

    @_builtins.property
    @pulumi.getter(name="enableProductionFeedback")
    def enable_production_feedback(self) -> pulumi.Output[_builtins.str]:
        """
        Enables the Vercel Toolbar on your production deployments: one of on, off or default.
        """
        return pulumi.get(self, "enable_production_feedback")

    @_builtins.property
    @pulumi.getter(name="hideIpAddresses")
    def hide_ip_addresses(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates if ip addresses should be accessible in o11y tooling.
        """
        return pulumi.get(self, "hide_ip_addresses")

    @_builtins.property
    @pulumi.getter(name="hideIpAddressesInLogDrains")
    def hide_ip_addresses_in_log_drains(self) -> pulumi.Output[_builtins.bool]:
        """
        Indicates if ip addresses should be accessible in log drains.
        """
        return pulumi.get(self, "hide_ip_addresses_in_log_drains")

    @_builtins.property
    @pulumi.getter(name="inviteCode")
    def invite_code(self) -> pulumi.Output[_builtins.str]:
        """
        A code that can be used to join this team. Only visible to Team owners.
        """
        return pulumi.get(self, "invite_code")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the team.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="previewDeploymentSuffix")
    def preview_deployment_suffix(self) -> pulumi.Output[_builtins.str]:
        """
        The hostname that is used as the preview deployment suffix.
        """
        return pulumi.get(self, "preview_deployment_suffix")

    @_builtins.property
    @pulumi.getter(name="remoteCaching")
    def remote_caching(self) -> pulumi.Output['outputs.TeamConfigRemoteCaching']:
        """
        Configuration for Remote Caching.
        """
        return pulumi.get(self, "remote_caching")

    @_builtins.property
    @pulumi.getter
    def saml(self) -> pulumi.Output['outputs.TeamConfigSaml']:
        """
        Configuration for SAML authentication.
        """
        return pulumi.get(self, "saml")

    @_builtins.property
    @pulumi.getter(name="sensitiveEnvironmentVariablePolicy")
    def sensitive_environment_variable_policy(self) -> pulumi.Output[_builtins.str]:
        """
        Ensures that all environment variables created by members of this team will be created as Sensitive Environment Variables which can only be decrypted by Vercel's deployment system.: one of on, off or default.
        """
        return pulumi.get(self, "sensitive_environment_variable_policy")

    @_builtins.property
    @pulumi.getter
    def slug(self) -> pulumi.Output[_builtins.str]:
        """
        The slug of the team. Will be used in the URL of the team's dashboard.
        """
        return pulumi.get(self, "slug")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['WebhookArgs', 'Webhook']

@pulumi.input_type
class WebhookArgs:
    def __init__(__self__, *,
                 endpoint: pulumi.Input[_builtins.str],
                 events: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Webhook resource.
        :param pulumi.Input[_builtins.str] endpoint: Webhooks events will be sent as POST requests to this URL.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] events: A list of the events the webhook will listen to. At least one must be present.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] project_ids: A list of project IDs that the webhook should be associated with. These projects should send events to the specified endpoint.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Webhook should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        pulumi.set(__self__, "endpoint", endpoint)
        pulumi.set(__self__, "events", events)
        if project_ids is not None:
            pulumi.set(__self__, "project_ids", project_ids)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> pulumi.Input[_builtins.str]:
        """
        Webhooks events will be sent as POST requests to this URL.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter
    def events(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        A list of the events the webhook will listen to. At least one must be present.
        """
        return pulumi.get(self, "events")

    @events.setter
    def events(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "events", value)

    @_builtins.property
    @pulumi.getter(name="projectIds")
    def project_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of project IDs that the webhook should be associated with. These projects should send events to the specified endpoint.
        """
        return pulumi.get(self, "project_ids")

    @project_ids.setter
    def project_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "project_ids", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the team the Webhook should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.input_type
class _WebhookState:
    def __init__(__self__, *,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 events: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 secret: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Webhook resources.
        :param pulumi.Input[_builtins.str] endpoint: Webhooks events will be sent as POST requests to this URL.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] events: A list of the events the webhook will listen to. At least one must be present.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] project_ids: A list of project IDs that the webhook should be associated with. These projects should send events to the specified endpoint.
        :param pulumi.Input[_builtins.str] secret: A secret value which will be provided in the `x-vercel-signature` header and can be used to verify the authenticity of the webhook. See https://vercel.com/docs/observability/webhooks-overview/webhooks-api#securing-webhooks for further details.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Webhook should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if events is not None:
            pulumi.set(__self__, "events", events)
        if project_ids is not None:
            pulumi.set(__self__, "project_ids", project_ids)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Webhooks events will be sent as POST requests to this URL.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter
    def events(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of the events the webhook will listen to. At least one must be present.
        """
        return pulumi.get(self, "events")

    @events.setter
    def events(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "events", value)

    @_builtins.property
    @pulumi.getter(name="projectIds")
    def project_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of project IDs that the webhook should be associated with. These projects should send events to the specified endpoint.
        """
        return pulumi.get(self, "project_ids")

    @project_ids.setter
    def project_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "project_ids", value)

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A secret value which will be provided in the `x-vercel-signature` header and can be used to verify the authenticity of the webhook. See https://vercel.com/docs/observability/webhooks-overview/webhooks-api#securing-webhooks for further details.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the team the Webhook should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.type_token("vercel:index/webhook:Webhook")
class Webhook(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 events: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        A webhook is a trigger-based HTTP endpoint configured to receive HTTP POST requests through events.

        When an event happens, a webhook is sent to a third-party app, which can then take appropriate action.

        > Only Pro and Enterprise teams are able to configure these webhooks at the account level.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        example = vercel.Project("example", name="example-project")
        example2 = vercel.Project("example2", name="another-example-project")
        with_project_ids = vercel.Webhook("with_project_ids",
            events=[
                "deployment.created",
                "deployment.succeeded",
            ],
            endpoint="https://example.com/endpoint",
            project_ids=[
                example.id,
                example2.id,
            ])
        without_project_ids = vercel.Webhook("without_project_ids",
            events=[
                "deployment.created",
                "deployment.succeeded",
            ],
            endpoint="https://example.com/endpoint")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] endpoint: Webhooks events will be sent as POST requests to this URL.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] events: A list of the events the webhook will listen to. At least one must be present.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] project_ids: A list of project IDs that the webhook should be associated with. These projects should send events to the specified endpoint.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Webhook should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WebhookArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        A webhook is a trigger-based HTTP endpoint configured to receive HTTP POST requests through events.

        When an event happens, a webhook is sent to a third-party app, which can then take appropriate action.

        > Only Pro and Enterprise teams are able to configure these webhooks at the account level.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        example = vercel.Project("example", name="example-project")
        example2 = vercel.Project("example2", name="another-example-project")
        with_project_ids = vercel.Webhook("with_project_ids",
            events=[
                "deployment.created",
                "deployment.succeeded",
            ],
            endpoint="https://example.com/endpoint",
            project_ids=[
                example.id,
                example2.id,
            ])
        without_project_ids = vercel.Webhook("without_project_ids",
            events=[
                "deployment.created",
                "deployment.succeeded",
            ],
            endpoint="https://example.com/endpoint")
        ```

        :param str resource_name: The name of the resource.
        :param WebhookArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WebhookArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 events: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WebhookArgs.__new__(WebhookArgs)

            if endpoint is None and not opts.urn:
                raise TypeError("Missing required property 'endpoint'")
            __props__.__dict__["endpoint"] = endpoint
            if events is None and not opts.urn:
                raise TypeError("Missing required property 'events'")
            __props__.__dict__["events"] = events
            __props__.__dict__["project_ids"] = project_ids
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["secret"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Webhook, __self__).__init__(
            'vercel:index/webhook:Webhook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            events: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            project_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            secret: Optional[pulumi.Input[_builtins.str]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Webhook':
        """
        Get an existing Webhook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] endpoint: Webhooks events will be sent as POST requests to this URL.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] events: A list of the events the webhook will listen to. At least one must be present.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] project_ids: A list of project IDs that the webhook should be associated with. These projects should send events to the specified endpoint.
        :param pulumi.Input[_builtins.str] secret: A secret value which will be provided in the `x-vercel-signature` header and can be used to verify the authenticity of the webhook. See https://vercel.com/docs/observability/webhooks-overview/webhooks-api#securing-webhooks for further details.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Webhook should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WebhookState.__new__(_WebhookState)

        __props__.__dict__["endpoint"] = endpoint
        __props__.__dict__["events"] = events
        __props__.__dict__["project_ids"] = project_ids
        __props__.__dict__["secret"] = secret
        __props__.__dict__["team_id"] = team_id
        return Webhook(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output[_builtins.str]:
        """
        Webhooks events will be sent as POST requests to this URL.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def events(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of the events the webhook will listen to. At least one must be present.
        """
        return pulumi.get(self, "events")

    @_builtins.property
    @pulumi.getter(name="projectIds")
    def project_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of project IDs that the webhook should be associated with. These projects should send events to the specified endpoint.
        """
        return pulumi.get(self, "project_ids")

    @_builtins.property
    @pulumi.getter
    def secret(self) -> pulumi.Output[_builtins.str]:
        """
        A secret value which will be provided in the `x-vercel-signature` header and can be used to verify the authenticity of the webhook. See https://vercel.com/docs/observability/webhooks-overview/webhooks-api#securing-webhooks for further details.
        """
        return pulumi.get(self, "secret")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the team the Webhook should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetMicrofrontendGroupMembershipResult',
    'AwaitableGetMicrofrontendGroupMembershipResult',
    'get_microfrontend_group_membership',
    'get_microfrontend_group_membership_output',
]

@pulumi.output_type
class GetMicrofrontendGroupMembershipResult:
    """
    A collection of values returned by getMicrofrontendGroupMembership.
    """
    def __init__(__self__, default_route=None, id=None, microfrontend_group_id=None, project_id=None, route_observability_to_this_project=None, team_id=None):
        if default_route and not isinstance(default_route, str):
            raise TypeError("Expected argument 'default_route' to be a str")
        pulumi.set(__self__, "default_route", default_route)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if microfrontend_group_id and not isinstance(microfrontend_group_id, str):
            raise TypeError("Expected argument 'microfrontend_group_id' to be a str")
        pulumi.set(__self__, "microfrontend_group_id", microfrontend_group_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if route_observability_to_this_project and not isinstance(route_observability_to_this_project, bool):
            raise TypeError("Expected argument 'route_observability_to_this_project' to be a bool")
        pulumi.set(__self__, "route_observability_to_this_project", route_observability_to_this_project)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="defaultRoute")
    def default_route(self) -> _builtins.str:
        """
        The default route for the project. Used for the screenshot of deployments.
        """
        return pulumi.get(self, "default_route")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier for this resource. Format: team*id/microfrontend*group_id.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="microfrontendGroupId")
    def microfrontend_group_id(self) -> _builtins.str:
        """
        The ID of the microfrontend group.
        """
        return pulumi.get(self, "microfrontend_group_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="routeObservabilityToThisProject")
    def route_observability_to_this_project(self) -> _builtins.bool:
        """
        Whether the project is route observability for this project. If dalse, the project will be route observability for all projects to the default project.
        """
        return pulumi.get(self, "route_observability_to_this_project")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The team ID to add the microfrontend group to. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")


class AwaitableGetMicrofrontendGroupMembershipResult(GetMicrofrontendGroupMembershipResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMicrofrontendGroupMembershipResult(
            default_route=self.default_route,
            id=self.id,
            microfrontend_group_id=self.microfrontend_group_id,
            project_id=self.project_id,
            route_observability_to_this_project=self.route_observability_to_this_project,
            team_id=self.team_id)


def get_microfrontend_group_membership(microfrontend_group_id: Optional[_builtins.str] = None,
                                       project_id: Optional[_builtins.str] = None,
                                       team_id: Optional[_builtins.str] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMicrofrontendGroupMembershipResult:
    """
    Provides information about an existing Microfrontend Group Membership.

    A Microfrontend Group Membership is a definition of a Vercel Project being a part of a Microfrontend Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_microfrontend_group_membership(project_id="prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        microfrontend_group_id="mfe_xxxxxxxxxxxxxxxxxxxxxxxxxxxx")
    ```


    :param _builtins.str microfrontend_group_id: The ID of the microfrontend group.
    :param _builtins.str project_id: The ID of the project.
    :param _builtins.str team_id: The team ID to add the microfrontend group to. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['microfrontendGroupId'] = microfrontend_group_id
    __args__['projectId'] = project_id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getMicrofrontendGroupMembership:getMicrofrontendGroupMembership', __args__, opts=opts, typ=GetMicrofrontendGroupMembershipResult).value

    return AwaitableGetMicrofrontendGroupMembershipResult(
        default_route=pulumi.get(__ret__, 'default_route'),
        id=pulumi.get(__ret__, 'id'),
        microfrontend_group_id=pulumi.get(__ret__, 'microfrontend_group_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        route_observability_to_this_project=pulumi.get(__ret__, 'route_observability_to_this_project'),
        team_id=pulumi.get(__ret__, 'team_id'))
def get_microfrontend_group_membership_output(microfrontend_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                                              project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                              team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMicrofrontendGroupMembershipResult]:
    """
    Provides information about an existing Microfrontend Group Membership.

    A Microfrontend Group Membership is a definition of a Vercel Project being a part of a Microfrontend Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_microfrontend_group_membership(project_id="prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        microfrontend_group_id="mfe_xxxxxxxxxxxxxxxxxxxxxxxxxxxx")
    ```


    :param _builtins.str microfrontend_group_id: The ID of the microfrontend group.
    :param _builtins.str project_id: The ID of the project.
    :param _builtins.str team_id: The team ID to add the microfrontend group to. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['microfrontendGroupId'] = microfrontend_group_id
    __args__['projectId'] = project_id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getMicrofrontendGroupMembership:getMicrofrontendGroupMembership', __args__, opts=opts, typ=GetMicrofrontendGroupMembershipResult)
    return __ret__.apply(lambda __response__: GetMicrofrontendGroupMembershipResult(
        default_route=pulumi.get(__response__, 'default_route'),
        id=pulumi.get(__response__, 'id'),
        microfrontend_group_id=pulumi.get(__response__, 'microfrontend_group_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        route_observability_to_this_project=pulumi.get(__response__, 'route_observability_to_this_project'),
        team_id=pulumi.get(__response__, 'team_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetDsyncGroupsResult',
    'AwaitableGetDsyncGroupsResult',
    'get_dsync_groups',
    'get_dsync_groups_output',
]

@pulumi.output_type
class GetDsyncGroupsResult:
    """
    A collection of values returned by getDsyncGroups.
    """
    def __init__(__self__, id=None, lists=None, map=None, team_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lists and not isinstance(lists, list):
            raise TypeError("Expected argument 'lists' to be a list")
        pulumi.set(__self__, "lists", lists)
        if map and not isinstance(map, dict):
            raise TypeError("Expected argument 'map' to be a dict")
        pulumi.set(__self__, "map", map)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def lists(self) -> Sequence['outputs.GetDsyncGroupsListResult']:
        """
        A list of DSync groups for the team.
        """
        return pulumi.get(self, "lists")

    @_builtins.property
    @pulumi.getter
    def map(self) -> Mapping[str, _builtins.str]:
        """
        A map of Identity Provider group names to their Vercel IDs. This can be used to look up the ID of a group by its name using the lookup function.
        """
        return pulumi.get(self, "map")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The ID of the team the Dsync Groups are associated to. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")


class AwaitableGetDsyncGroupsResult(GetDsyncGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDsyncGroupsResult(
            id=self.id,
            lists=self.lists,
            map=self.map,
            team_id=self.team_id)


def get_dsync_groups(team_id: Optional[_builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDsyncGroupsResult:
    """
    Provides information about DSync groups for a team.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_std as std
    import pulumi_vercel as vercel
    import pulumiverse_vercel as vercel

    example = vercel.get_dsync_groups(team_id="team_xxxxxxxxxxxxxxxxxxxxxxxxxxxx")
    contractor = vercel.AccessGroup("contractor",
        team_id="team_xxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        name="contractor",
        description="Access group for contractors")
    example_team_config = vercel.TeamConfig("example",
        id="team_xxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        saml={
            "enforced": True,
            "roles": {
                std.index.lookup(map=example_vercel_dsync_groups["map"],
                    key="admin")["result"]: {
                    "role": "OWNER",
                },
                std.index.lookup(map=example_vercel_dsync_groups["map"],
                    key="finance")["result"]: {
                    "role": "BILLING",
                },
                std.index.lookup(map=example_vercel_dsync_groups["map"],
                    key="contractor")["result"]: {
                    "role": "CONTRIBUTOR",
                    "accessGroupId": contractor.id,
                },
            },
        })
    ```


    :param _builtins.str team_id: The ID of the team the Dsync Groups are associated to. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getDsyncGroups:getDsyncGroups', __args__, opts=opts, typ=GetDsyncGroupsResult).value

    return AwaitableGetDsyncGroupsResult(
        id=pulumi.get(__ret__, 'id'),
        lists=pulumi.get(__ret__, 'lists'),
        map=pulumi.get(__ret__, 'map'),
        team_id=pulumi.get(__ret__, 'team_id'))
def get_dsync_groups_output(team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDsyncGroupsResult]:
    """
    Provides information about DSync groups for a team.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_std as std
    import pulumi_vercel as vercel
    import pulumiverse_vercel as vercel

    example = vercel.get_dsync_groups(team_id="team_xxxxxxxxxxxxxxxxxxxxxxxxxxxx")
    contractor = vercel.AccessGroup("contractor",
        team_id="team_xxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        name="contractor",
        description="Access group for contractors")
    example_team_config = vercel.TeamConfig("example",
        id="team_xxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        saml={
            "enforced": True,
            "roles": {
                std.index.lookup(map=example_vercel_dsync_groups["map"],
                    key="admin")["result"]: {
                    "role": "OWNER",
                },
                std.index.lookup(map=example_vercel_dsync_groups["map"],
                    key="finance")["result"]: {
                    "role": "BILLING",
                },
                std.index.lookup(map=example_vercel_dsync_groups["map"],
                    key="contractor")["result"]: {
                    "role": "CONTRIBUTOR",
                    "accessGroupId": contractor.id,
                },
            },
        })
    ```


    :param _builtins.str team_id: The ID of the team the Dsync Groups are associated to. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getDsyncGroups:getDsyncGroups', __args__, opts=opts, typ=GetDsyncGroupsResult)
    return __ret__.apply(lambda __response__: GetDsyncGroupsResult(
        id=pulumi.get(__response__, 'id'),
        lists=pulumi.get(__response__, 'lists'),
        map=pulumi.get(__response__, 'map'),
        team_id=pulumi.get(__response__, 'team_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAccessGroupProjectResult',
    'AwaitableGetAccessGroupProjectResult',
    'get_access_group_project',
    'get_access_group_project_output',
]

@pulumi.output_type
class GetAccessGroupProjectResult:
    """
    A collection of values returned by getAccessGroupProject.
    """
    def __init__(__self__, access_group_id=None, id=None, project_id=None, role=None, team_id=None):
        if access_group_id and not isinstance(access_group_id, str):
            raise TypeError("Expected argument 'access_group_id' to be a str")
        pulumi.set(__self__, "access_group_id", access_group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if role and not isinstance(role, str):
            raise TypeError("Expected argument 'role' to be a str")
        pulumi.set(__self__, "role", role)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="accessGroupId")
    def access_group_id(self) -> _builtins.str:
        """
        The Access Group ID.
        """
        return pulumi.get(self, "access_group_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier for this resource. Format: access*group*id/project_id.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The Project ID.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def role(self) -> _builtins.str:
        """
        The Access Group Project Role.
        """
        return pulumi.get(self, "role")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The ID of the team the Access Group Project should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")


class AwaitableGetAccessGroupProjectResult(GetAccessGroupProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccessGroupProjectResult(
            access_group_id=self.access_group_id,
            id=self.id,
            project_id=self.project_id,
            role=self.role,
            team_id=self.team_id)


def get_access_group_project(access_group_id: Optional[_builtins.str] = None,
                             project_id: Optional[_builtins.str] = None,
                             team_id: Optional[_builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccessGroupProjectResult:
    """
    Provides information about an existing Access Group Project Assignment.

    For more detailed information, please see the [Vercel documentation](https://vercel.com/docs/accounts/team-members-and-roles/access-groups).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_project(name="my-existing-project")
    example_get_access_group_project = vercel.get_access_group_project(access_group_id="ag_xxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        project_id=example_vercel_project["id"])
    ```


    :param _builtins.str access_group_id: The Access Group ID.
    :param _builtins.str project_id: The Project ID.
    :param _builtins.str team_id: The ID of the team the Access Group Project should exist under. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['accessGroupId'] = access_group_id
    __args__['projectId'] = project_id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getAccessGroupProject:getAccessGroupProject', __args__, opts=opts, typ=GetAccessGroupProjectResult).value

    return AwaitableGetAccessGroupProjectResult(
        access_group_id=pulumi.get(__ret__, 'access_group_id'),
        id=pulumi.get(__ret__, 'id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        role=pulumi.get(__ret__, 'role'),
        team_id=pulumi.get(__ret__, 'team_id'))
def get_access_group_project_output(access_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                                    project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                    team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccessGroupProjectResult]:
    """
    Provides information about an existing Access Group Project Assignment.

    For more detailed information, please see the [Vercel documentation](https://vercel.com/docs/accounts/team-members-and-roles/access-groups).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_project(name="my-existing-project")
    example_get_access_group_project = vercel.get_access_group_project(access_group_id="ag_xxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        project_id=example_vercel_project["id"])
    ```


    :param _builtins.str access_group_id: The Access Group ID.
    :param _builtins.str project_id: The Project ID.
    :param _builtins.str team_id: The ID of the team the Access Group Project should exist under. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['accessGroupId'] = access_group_id
    __args__['projectId'] = project_id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getAccessGroupProject:getAccessGroupProject', __args__, opts=opts, typ=GetAccessGroupProjectResult)
    return __ret__.apply(lambda __response__: GetAccessGroupProjectResult(
        access_group_id=pulumi.get(__response__, 'access_group_id'),
        id=pulumi.get(__response__, 'id'),
        project_id=pulumi.get(__response__, 'project_id'),
        role=pulumi.get(__response__, 'role'),
        team_id=pulumi.get(__response__, 'team_id')))
